# This Source Code Form is subject to the terms of the Mozilla Public
# License, v. 2.0. If a copy of the MPL was not distributed with this
# file, You can obtain one at https://mozilla.org/MPL/2.0/.

import io
import queue
from typing import AnyStr, Generator, TextIO

from saturn_bot import controller
from saturn_bot.plugin import grpc_stdio_pb2, grpc_stdio_pb2_grpc


class Adapter(TextIO):
    """
    Adapter implements all methods needed to replace default stderr and stdout
    IO objects.
    Any message written to it is being put into a queue.
    """

    def __init__(self, channel: grpc_stdio_pb2.StdioData.Channel, q: queue.SimpleQueue):
        self._chan = channel
        self._q = q

    def __exit__(self, __type, __value, __traceback):
        raise io.UnsupportedOperation()

    def __iter__(self):
        raise io.UnsupportedOperation()

    def __next__(self):
        raise io.UnsupportedOperation()

    def writelines(self, __lines):
        raise io.UnsupportedOperation()

    def writable(self):
        raise io.UnsupportedOperation()

    def truncate(self, __size=None):
        raise io.UnsupportedOperation()

    def tell(self):
        raise io.UnsupportedOperation()

    def seekable(self):
        raise io.UnsupportedOperation()

    def seek(self, __offset, __whence=0):
        raise io.UnsupportedOperation()

    def readlines(self, __hint=-1):
        raise io.UnsupportedOperation()

    def readline(self, __limit=-1):
        raise io.UnsupportedOperation()

    def readable(self):
        raise io.UnsupportedOperation()

    def read(self, __n=-1):
        raise io.UnsupportedOperation()

    def isatty(self):
        raise io.UnsupportedOperation()

    def fileno(self):
        raise io.UnsupportedOperation()

    def close(self):
        raise io.UnsupportedOperation()

    def __enter__(self):
        raise io.UnsupportedOperation()

    def flush(self):
        """
        flush implements TextIO.
        """
        while True:
            if self._q.empty() is True:
                return

    def write(self, msg: AnyStr) -> int:
        """
        write implements TextIO.
        """
        if isinstance(msg, str):
            data = msg.encode("utf-8")
        else:
            data = msg

        self._q.put_nowait(grpc_stdio_pb2.StdioData(channel=self._chan, data=data))
        return len(msg)


class Servicer(grpc_stdio_pb2_grpc.GRPCStdioServicer):
    """
    StdioServicer streams output to the main process of saturn-bot via gRPC.
    """

    def __init__(self, q: queue.SimpleQueue, shutdown_ctrl: controller.Servicer):
        self._q = q
        self._shutdown_ctrl = shutdown_ctrl

    def StreamStdio(
        self, request, context
    ) -> Generator[grpc_stdio_pb2.StdioData, None, None]:
        """
        StreamStdio implements GRPCStdioServicer.
        It reads the messages to forward from a queue.
        """
        while True:
            try:
                entry: grpc_stdio_pb2.StdioData = self._q.get(block=True, timeout=0.1)
                yield entry
            except queue.Empty:
                pass

            if self._shutdown_ctrl.is_shut_down is True:
                return



# This Source Code Form is subject to the terms of the Mozilla Public
# License, v. 2.0. If a copy of the MPL was not distributed with this
# file, You can obtain one at https://mozilla.org/MPL/2.0/.

# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from saturn_bot.plugin import grpc_controller_pb2 as saturn__bot_dot_plugin_dot_grpc__controller__pb2


class GRPCControllerStub(object):
    """The GRPCController is responsible for telling the plugin server to shutdown.
    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.Shutdown = channel.unary_unary(
                '/plugin.GRPCController/Shutdown',
                request_serializer=saturn__bot_dot_plugin_dot_grpc__controller__pb2.Empty.SerializeToString,
                response_deserializer=saturn__bot_dot_plugin_dot_grpc__controller__pb2.Empty.FromString,
                )


class GRPCControllerServicer(object):
    """The GRPCController is responsible for telling the plugin server to shutdown.
    """

    def Shutdown(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_GRPCControllerServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'Shutdown': grpc.unary_unary_rpc_method_handler(
                    servicer.Shutdown,
                    request_deserializer=saturn__bot_dot_plugin_dot_grpc__controller__pb2.Empty.FromString,
                    response_serializer=saturn__bot_dot_plugin_dot_grpc__controller__pb2.Empty.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'plugin.GRPCController', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class GRPCController(object):
    """The GRPCController is responsible for telling the plugin server to shutdown.
    """

    @staticmethod
    def Shutdown(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/plugin.GRPCController/Shutdown',
            saturn__bot_dot_plugin_dot_grpc__controller__pb2.Empty.SerializeToString,
            saturn__bot_dot_plugin_dot_grpc__controller__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



# This Source Code Form is subject to the terms of the Mozilla Public
# License, v. 2.0. If a copy of the MPL was not distributed with this
# file, You can obtain one at https://mozilla.org/MPL/2.0/.

# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from saturn_bot.protocol.v1 import saturnbot_pb2 as saturn__bot_dot_protocol_dot_v1_dot_saturnbot__pb2


class PluginServiceStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.ExecuteActions = channel.unary_unary(
                '/protocol.v1.PluginService/ExecuteActions',
                request_serializer=saturn__bot_dot_protocol_dot_v1_dot_saturnbot__pb2.ExecuteActionsRequest.SerializeToString,
                response_deserializer=saturn__bot_dot_protocol_dot_v1_dot_saturnbot__pb2.ExecuteActionsResponse.FromString,
                )
        self.ExecuteFilters = channel.unary_unary(
                '/protocol.v1.PluginService/ExecuteFilters',
                request_serializer=saturn__bot_dot_protocol_dot_v1_dot_saturnbot__pb2.ExecuteFiltersRequest.SerializeToString,
                response_deserializer=saturn__bot_dot_protocol_dot_v1_dot_saturnbot__pb2.ExecuteFiltersResponse.FromString,
                )
        self.GetPlugin = channel.unary_unary(
                '/protocol.v1.PluginService/GetPlugin',
                request_serializer=saturn__bot_dot_protocol_dot_v1_dot_saturnbot__pb2.GetPluginRequest.SerializeToString,
                response_deserializer=saturn__bot_dot_protocol_dot_v1_dot_saturnbot__pb2.GetPluginResponse.FromString,
                )
        self.OnPrClosed = channel.unary_unary(
                '/protocol.v1.PluginService/OnPrClosed',
                request_serializer=saturn__bot_dot_protocol_dot_v1_dot_saturnbot__pb2.OnPrClosedRequest.SerializeToString,
                response_deserializer=saturn__bot_dot_protocol_dot_v1_dot_saturnbot__pb2.OnPrClosedResponse.FromString,
                )
        self.OnPrCreated = channel.unary_unary(
                '/protocol.v1.PluginService/OnPrCreated',
                request_serializer=saturn__bot_dot_protocol_dot_v1_dot_saturnbot__pb2.OnPrCreatedRequest.SerializeToString,
                response_deserializer=saturn__bot_dot_protocol_dot_v1_dot_saturnbot__pb2.OnPrCreatedResponse.FromString,
                )
        self.OnPrMerged = channel.unary_unary(
                '/protocol.v1.PluginService/OnPrMerged',
                request_serializer=saturn__bot_dot_protocol_dot_v1_dot_saturnbot__pb2.OnPrMergedRequest.SerializeToString,
                response_deserializer=saturn__bot_dot_protocol_dot_v1_dot_saturnbot__pb2.OnPrMergedResponse.FromString,
                )


class PluginServiceServicer(object):
    """Missing associated documentation comment in .proto file."""

    def ExecuteActions(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ExecuteFilters(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetPlugin(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def OnPrClosed(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def OnPrCreated(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def OnPrMerged(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_PluginServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'ExecuteActions': grpc.unary_unary_rpc_method_handler(
                    servicer.ExecuteActions,
                    request_deserializer=saturn__bot_dot_protocol_dot_v1_dot_saturnbot__pb2.ExecuteActionsRequest.FromString,
                    response_serializer=saturn__bot_dot_protocol_dot_v1_dot_saturnbot__pb2.ExecuteActionsResponse.SerializeToString,
            ),
            'ExecuteFilters': grpc.unary_unary_rpc_method_handler(
                    servicer.ExecuteFilters,
                    request_deserializer=saturn__bot_dot_protocol_dot_v1_dot_saturnbot__pb2.ExecuteFiltersRequest.FromString,
                    response_serializer=saturn__bot_dot_protocol_dot_v1_dot_saturnbot__pb2.ExecuteFiltersResponse.SerializeToString,
            ),
            'GetPlugin': grpc.unary_unary_rpc_method_handler(
                    servicer.GetPlugin,
                    request_deserializer=saturn__bot_dot_protocol_dot_v1_dot_saturnbot__pb2.GetPluginRequest.FromString,
                    response_serializer=saturn__bot_dot_protocol_dot_v1_dot_saturnbot__pb2.GetPluginResponse.SerializeToString,
            ),
            'OnPrClosed': grpc.unary_unary_rpc_method_handler(
                    servicer.OnPrClosed,
                    request_deserializer=saturn__bot_dot_protocol_dot_v1_dot_saturnbot__pb2.OnPrClosedRequest.FromString,
                    response_serializer=saturn__bot_dot_protocol_dot_v1_dot_saturnbot__pb2.OnPrClosedResponse.SerializeToString,
            ),
            'OnPrCreated': grpc.unary_unary_rpc_method_handler(
                    servicer.OnPrCreated,
                    request_deserializer=saturn__bot_dot_protocol_dot_v1_dot_saturnbot__pb2.OnPrCreatedRequest.FromString,
                    response_serializer=saturn__bot_dot_protocol_dot_v1_dot_saturnbot__pb2.OnPrCreatedResponse.SerializeToString,
            ),
            'OnPrMerged': grpc.unary_unary_rpc_method_handler(
                    servicer.OnPrMerged,
                    request_deserializer=saturn__bot_dot_protocol_dot_v1_dot_saturnbot__pb2.OnPrMergedRequest.FromString,
                    response_serializer=saturn__bot_dot_protocol_dot_v1_dot_saturnbot__pb2.OnPrMergedResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'protocol.v1.PluginService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class PluginService(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def ExecuteActions(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/protocol.v1.PluginService/ExecuteActions',
            saturn__bot_dot_protocol_dot_v1_dot_saturnbot__pb2.ExecuteActionsRequest.SerializeToString,
            saturn__bot_dot_protocol_dot_v1_dot_saturnbot__pb2.ExecuteActionsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ExecuteFilters(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/protocol.v1.PluginService/ExecuteFilters',
            saturn__bot_dot_protocol_dot_v1_dot_saturnbot__pb2.ExecuteFiltersRequest.SerializeToString,
            saturn__bot_dot_protocol_dot_v1_dot_saturnbot__pb2.ExecuteFiltersResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetPlugin(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/protocol.v1.PluginService/GetPlugin',
            saturn__bot_dot_protocol_dot_v1_dot_saturnbot__pb2.GetPluginRequest.SerializeToString,
            saturn__bot_dot_protocol_dot_v1_dot_saturnbot__pb2.GetPluginResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def OnPrClosed(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/protocol.v1.PluginService/OnPrClosed',
            saturn__bot_dot_protocol_dot_v1_dot_saturnbot__pb2.OnPrClosedRequest.SerializeToString,
            saturn__bot_dot_protocol_dot_v1_dot_saturnbot__pb2.OnPrClosedResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def OnPrCreated(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/protocol.v1.PluginService/OnPrCreated',
            saturn__bot_dot_protocol_dot_v1_dot_saturnbot__pb2.OnPrCreatedRequest.SerializeToString,
            saturn__bot_dot_protocol_dot_v1_dot_saturnbot__pb2.OnPrCreatedResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def OnPrMerged(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/protocol.v1.PluginService/OnPrMerged',
            saturn__bot_dot_protocol_dot_v1_dot_saturnbot__pb2.OnPrMergedRequest.SerializeToString,
            saturn__bot_dot_protocol_dot_v1_dot_saturnbot__pb2.OnPrMergedResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



# -*- coding: utf-8 -*-
# This Source Code Form is subject to the terms of the Mozilla Public
# License, v. 2.0. If a copy of the MPL was not distributed with this
# file, You can obtain one at https://mozilla.org/MPL/2.0/.

# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: saturn_bot/plugin/grpc_controller.proto
# Protobuf Python Version: 4.25.3
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\'saturn_bot/plugin/grpc_controller.proto\x12\x06plugin\"\x07\n\x05\x45mpty2:\n\x0eGRPCController\x12(\n\x08Shutdown\x12\r.plugin.Empty\x1a\r.plugin.EmptyBc\n\ncom.pluginB\x13GrpcControllerProtoP\x01Z\x08./plugin\xa2\x02\x03PXX\xaa\x02\x06Plugin\xca\x02\x06Plugin\xe2\x02\x12Plugin\\GPBMetadata\xea\x02\x06Pluginb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'saturn_bot.plugin.grpc_controller_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  _globals['DESCRIPTOR']._options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\ncom.pluginB\023GrpcControllerProtoP\001Z\010./plugin\242\002\003PXX\252\002\006Plugin\312\002\006Plugin\342\002\022Plugin\\GPBMetadata\352\002\006Plugin'
  _globals['_EMPTY']._serialized_start=51
  _globals['_EMPTY']._serialized_end=58
  _globals['_GRPCCONTROLLER']._serialized_start=60
  _globals['_GRPCCONTROLLER']._serialized_end=118
# @@protoc_insertion_point(module_scope)



# This Source Code Form is subject to the terms of the Mozilla Public
# License, v. 2.0. If a copy of the MPL was not distributed with this
# file, You can obtain one at https://mozilla.org/MPL/2.0/.

from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class ExecuteActionsRequest(_message.Message):
    __slots__ = ("path", "context")
    PATH_FIELD_NUMBER: _ClassVar[int]
    CONTEXT_FIELD_NUMBER: _ClassVar[int]
    path: str
    context: Context
    def __init__(self, path: _Optional[str] = ..., context: _Optional[_Union[Context, _Mapping]] = ...) -> None: ...

class ExecuteActionsResponse(_message.Message):
    __slots__ = ("error", "run_data")
    class RunDataEntry(_message.Message):
        __slots__ = ("key", "value")
        KEY_FIELD_NUMBER: _ClassVar[int]
        VALUE_FIELD_NUMBER: _ClassVar[int]
        key: str
        value: str
        def __init__(self, key: _Optional[str] = ..., value: _Optional[str] = ...) -> None: ...
    ERROR_FIELD_NUMBER: _ClassVar[int]
    RUN_DATA_FIELD_NUMBER: _ClassVar[int]
    error: str
    run_data: _containers.ScalarMap[str, str]
    def __init__(self, error: _Optional[str] = ..., run_data: _Optional[_Mapping[str, str]] = ...) -> None: ...

class ExecuteFiltersRequest(_message.Message):
    __slots__ = ("context",)
    CONTEXT_FIELD_NUMBER: _ClassVar[int]
    context: Context
    def __init__(self, context: _Optional[_Union[Context, _Mapping]] = ...) -> None: ...

class ExecuteFiltersResponse(_message.Message):
    __slots__ = ("match", "error", "run_data")
    class RunDataEntry(_message.Message):
        __slots__ = ("key", "value")
        KEY_FIELD_NUMBER: _ClassVar[int]
        VALUE_FIELD_NUMBER: _ClassVar[int]
        key: str
        value: str
        def __init__(self, key: _Optional[str] = ..., value: _Optional[str] = ...) -> None: ...
    MATCH_FIELD_NUMBER: _ClassVar[int]
    ERROR_FIELD_NUMBER: _ClassVar[int]
    RUN_DATA_FIELD_NUMBER: _ClassVar[int]
    match: bool
    error: str
    run_data: _containers.ScalarMap[str, str]
    def __init__(self, match: bool = ..., error: _Optional[str] = ..., run_data: _Optional[_Mapping[str, str]] = ...) -> None: ...

class GetPluginRequest(_message.Message):
    __slots__ = ("config",)
    class ConfigEntry(_message.Message):
        __slots__ = ("key", "value")
        KEY_FIELD_NUMBER: _ClassVar[int]
        VALUE_FIELD_NUMBER: _ClassVar[int]
        key: str
        value: str
        def __init__(self, key: _Optional[str] = ..., value: _Optional[str] = ...) -> None: ...
    CONFIG_FIELD_NUMBER: _ClassVar[int]
    config: _containers.ScalarMap[str, str]
    def __init__(self, config: _Optional[_Mapping[str, str]] = ...) -> None: ...

class GetPluginResponse(_message.Message):
    __slots__ = ("name", "priority", "error")
    NAME_FIELD_NUMBER: _ClassVar[int]
    PRIORITY_FIELD_NUMBER: _ClassVar[int]
    ERROR_FIELD_NUMBER: _ClassVar[int]
    name: str
    priority: int
    error: str
    def __init__(self, name: _Optional[str] = ..., priority: _Optional[int] = ..., error: _Optional[str] = ...) -> None: ...

class Context(_message.Message):
    __slots__ = ("repository", "pull_request", "run_data")
    class RunDataEntry(_message.Message):
        __slots__ = ("key", "value")
        KEY_FIELD_NUMBER: _ClassVar[int]
        VALUE_FIELD_NUMBER: _ClassVar[int]
        key: str
        value: str
        def __init__(self, key: _Optional[str] = ..., value: _Optional[str] = ...) -> None: ...
    REPOSITORY_FIELD_NUMBER: _ClassVar[int]
    PULL_REQUEST_FIELD_NUMBER: _ClassVar[int]
    RUN_DATA_FIELD_NUMBER: _ClassVar[int]
    repository: Repository
    pull_request: PullRequest
    run_data: _containers.ScalarMap[str, str]
    def __init__(self, repository: _Optional[_Union[Repository, _Mapping]] = ..., pull_request: _Optional[_Union[PullRequest, _Mapping]] = ..., run_data: _Optional[_Mapping[str, str]] = ...) -> None: ...

class PullRequest(_message.Message):
    __slots__ = ("number", "web_url")
    NUMBER_FIELD_NUMBER: _ClassVar[int]
    WEB_URL_FIELD_NUMBER: _ClassVar[int]
    number: int
    web_url: str
    def __init__(self, number: _Optional[int] = ..., web_url: _Optional[str] = ...) -> None: ...

class Repository(_message.Message):
    __slots__ = ("full_name", "clone_url_http", "clone_url_ssh", "web_url")
    FULL_NAME_FIELD_NUMBER: _ClassVar[int]
    CLONE_URL_HTTP_FIELD_NUMBER: _ClassVar[int]
    CLONE_URL_SSH_FIELD_NUMBER: _ClassVar[int]
    WEB_URL_FIELD_NUMBER: _ClassVar[int]
    full_name: str
    clone_url_http: str
    clone_url_ssh: str
    web_url: str
    def __init__(self, full_name: _Optional[str] = ..., clone_url_http: _Optional[str] = ..., clone_url_ssh: _Optional[str] = ..., web_url: _Optional[str] = ...) -> None: ...

class OnPrClosedRequest(_message.Message):
    __slots__ = ("context",)
    CONTEXT_FIELD_NUMBER: _ClassVar[int]
    context: Context
    def __init__(self, context: _Optional[_Union[Context, _Mapping]] = ...) -> None: ...

class OnPrClosedResponse(_message.Message):
    __slots__ = ("error",)
    ERROR_FIELD_NUMBER: _ClassVar[int]
    error: str
    def __init__(self, error: _Optional[str] = ...) -> None: ...

class OnPrCreatedRequest(_message.Message):
    __slots__ = ("context",)
    CONTEXT_FIELD_NUMBER: _ClassVar[int]
    context: Context
    def __init__(self, context: _Optional[_Union[Context, _Mapping]] = ...) -> None: ...

class OnPrCreatedResponse(_message.Message):
    __slots__ = ("error",)
    ERROR_FIELD_NUMBER: _ClassVar[int]
    error: str
    def __init__(self, error: _Optional[str] = ...) -> None: ...

class OnPrMergedRequest(_message.Message):
    __slots__ = ("context",)
    CONTEXT_FIELD_NUMBER: _ClassVar[int]
    context: Context
    def __init__(self, context: _Optional[_Union[Context, _Mapping]] = ...) -> None: ...

class OnPrMergedResponse(_message.Message):
    __slots__ = ("error",)
    ERROR_FIELD_NUMBER: _ClassVar[int]
    error: str
    def __init__(self, error: _Optional[str] = ...) -> None: ...



# -*- coding: utf-8 -*-
# This Source Code Form is subject to the terms of the Mozilla Public
# License, v. 2.0. If a copy of the MPL was not distributed with this
# file, You can obtain one at https://mozilla.org/MPL/2.0/.

# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: saturn_bot/plugin/grpc_stdio.proto
# Protobuf Python Version: 4.25.3
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\"saturn_bot/plugin/grpc_stdio.proto\x12\x06plugin\x1a\x1bgoogle/protobuf/empty.proto\"\x84\x01\n\tStdioData\x12\x33\n\x07\x63hannel\x18\x01 \x01(\x0e\x32\x19.plugin.StdioData.ChannelR\x07\x63hannel\x12\x12\n\x04\x64\x61ta\x18\x02 \x01(\x0cR\x04\x64\x61ta\".\n\x07\x43hannel\x12\x0b\n\x07INVALID\x10\x00\x12\n\n\x06STDOUT\x10\x01\x12\n\n\x06STDERR\x10\x02\x32G\n\tGRPCStdio\x12:\n\x0bStreamStdio\x12\x16.google.protobuf.Empty\x1a\x11.plugin.StdioData0\x01\x42^\n\ncom.pluginB\x0eGrpcStdioProtoP\x01Z\x08./plugin\xa2\x02\x03PXX\xaa\x02\x06Plugin\xca\x02\x06Plugin\xe2\x02\x12Plugin\\GPBMetadata\xea\x02\x06Pluginb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'saturn_bot.plugin.grpc_stdio_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  _globals['DESCRIPTOR']._options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\ncom.pluginB\016GrpcStdioProtoP\001Z\010./plugin\242\002\003PXX\252\002\006Plugin\312\002\006Plugin\342\002\022Plugin\\GPBMetadata\352\002\006Plugin'
  _globals['_STDIODATA']._serialized_start=76
  _globals['_STDIODATA']._serialized_end=208
  _globals['_STDIODATA_CHANNEL']._serialized_start=162
  _globals['_STDIODATA_CHANNEL']._serialized_end=208
  _globals['_GRPCSTDIO']._serialized_start=210
  _globals['_GRPCSTDIO']._serialized_end=281
# @@protoc_insertion_point(module_scope)



# This Source Code Form is subject to the terms of the Mozilla Public
# License, v. 2.0. If a copy of the MPL was not distributed with this
# file, You can obtain one at https://mozilla.org/MPL/2.0/.

from saturn_bot.sdk import Context, Plugin, serve_plugin

__all__ = [
    "Context",
    "Plugin",
    "serve_plugin",
]



# This Source Code Form is subject to the terms of the Mozilla Public
# License, v. 2.0. If a copy of the MPL was not distributed with this
# file, You can obtain one at https://mozilla.org/MPL/2.0/.

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar

DESCRIPTOR: _descriptor.FileDescriptor

class Empty(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...



# This Source Code Form is subject to the terms of the Mozilla Public
# License, v. 2.0. If a copy of the MPL was not distributed with this
# file, You can obtain one at https://mozilla.org/MPL/2.0/.

from google.protobuf import empty_pb2 as _empty_pb2
from google.protobuf.internal import enum_type_wrapper as _enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class StdioData(_message.Message):
    __slots__ = ("channel", "data")
    class Channel(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
        __slots__ = ()
        INVALID: _ClassVar[StdioData.Channel]
        STDOUT: _ClassVar[StdioData.Channel]
        STDERR: _ClassVar[StdioData.Channel]
    INVALID: StdioData.Channel
    STDOUT: StdioData.Channel
    STDERR: StdioData.Channel
    CHANNEL_FIELD_NUMBER: _ClassVar[int]
    DATA_FIELD_NUMBER: _ClassVar[int]
    channel: StdioData.Channel
    data: bytes
    def __init__(self, channel: _Optional[_Union[StdioData.Channel, str]] = ..., data: _Optional[bytes] = ...) -> None: ...



# This Source Code Form is subject to the terms of the Mozilla Public
# License, v. 2.0. If a copy of the MPL was not distributed with this
# file, You can obtain one at https://mozilla.org/MPL/2.0/.

import contextlib
import dataclasses
import errno
import os
import queue
import random
import socket
import sys
import time
import traceback
from concurrent import futures
from typing import Iterator, Mapping, MutableMapping

import grpc
from grpc_health.v1 import health_pb2, health_pb2_grpc
from grpc_health.v1.health import HealthServicer

from saturn_bot import controller, stdio
from saturn_bot.plugin import (
    grpc_controller_pb2_grpc,
    grpc_stdio_pb2,
    grpc_stdio_pb2_grpc,
)
from saturn_bot.protocol.v1 import saturnbot_pb2, saturnbot_pb2_grpc

BIND_IP: str = "127.0.0.1"

# Capture original streams for later use before stderr/stdout redirection.
sys_stderr = sys.stderr
sys_stdout = sys.stdout


@dataclasses.dataclass
class Context:
    pull_request: saturnbot_pb2.PullRequest
    repository: saturnbot_pb2.Repository
    run_data: MutableMapping[str, str]


class Plugin:
    name: str
    priority: int = 0

    def init(self, config: Mapping[str, str]) -> None:
        pass

    def apply(self, ctx: Context) -> None:
        return None

    def filter(self, ctx: Context) -> bool:
        return True

    def on_pr_closed(self, ctx: Context):
        pass

    def on_pr_created(self, ctx: Context):
        pass

    def on_pr_merged(self, ctx: Context):
        pass


@contextlib.contextmanager
def in_checkout_dir(d: str) -> Iterator[None]:
    current = os.getcwd()
    os.chdir(d)
    try:
        yield
    finally:
        os.chdir(current)


class PluginService(saturnbot_pb2_grpc.PluginServiceServicer):
    def __init__(self, p: Plugin):
        self._plugin = p

    def ExecuteActions(
        self, request: saturnbot_pb2.ExecuteActionsRequest, context
    ) -> saturnbot_pb2.ExecuteActionsResponse:
        ctx = Context(
            pull_request=request.context.pull_request,
            repository=request.context.repository,
            run_data=request.context.run_data,
        )
        try:
            with in_checkout_dir(request.path):
                self._plugin.apply(ctx=ctx)
        except Exception:
            return saturnbot_pb2.ExecuteActionsResponse(
                error=traceback.format_exc(),
            )

        return saturnbot_pb2.ExecuteActionsResponse(error=None, run_data=ctx.run_data)

    def ExecuteFilters(
        self, request: saturnbot_pb2.ExecuteFiltersRequest, context
    ) -> saturnbot_pb2.ExecuteFiltersResponse:
        ctx = Context(
            pull_request=request.context.pull_request,
            repository=request.context.repository,
            run_data=request.context.run_data,
        )
        try:
            result = self._plugin.filter(ctx=ctx)
            return saturnbot_pb2.ExecuteFiltersResponse(
                match=result,
                error=None,
                run_data=request.context.run_data,
            )
        except Exception:
            return saturnbot_pb2.ExecuteFiltersResponse(
                match=False,
                error=traceback.format_exc(),
            )

    def GetPlugin(
        self, request: saturnbot_pb2.GetPluginRequest, context
    ) -> saturnbot_pb2.GetPluginResponse:
        try:
            self._plugin.init(config=request.config)
            return saturnbot_pb2.GetPluginResponse(
                name=self._plugin.name, priority=self._plugin.priority, error=None
            )
        except Exception:
            return saturnbot_pb2.GetPluginResponse(
                error=traceback.format_exc(),
            )

    def OnPrClosed(
        self, request: saturnbot_pb2.OnPrClosedRequest, context
    ) -> saturnbot_pb2.OnPrClosedResponse:
        ctx = Context(
            pull_request=request.context.pull_request,
            repository=request.context.repository,
            run_data=request.context.run_data,
        )
        try:
            self._plugin.on_pr_closed(ctx=ctx)
            return saturnbot_pb2.OnPrClosedResponse(error=None)
        except Exception:
            return saturnbot_pb2.OnPrClosedResponse(
                error=traceback.format_exc(),
            )

    def OnPrCreated(
        self, request: saturnbot_pb2.OnPrCreatedRequest, context
    ) -> saturnbot_pb2.OnPrCreatedResponse:
        ctx = Context(
            pull_request=request.context.pull_request,
            repository=request.context.repository,
            run_data=request.context.run_data,
        )
        try:
            self._plugin.on_pr_created(ctx=ctx)
            return saturnbot_pb2.OnPrCreatedResponse(error=None)
        except Exception:
            return saturnbot_pb2.OnPrCreatedResponse(
                error=traceback.format_exc(),
            )

    def OnPrMerged(
        self, request: saturnbot_pb2.OnPrMergedRequest, context
    ) -> saturnbot_pb2.OnPrMergedResponse:
        ctx = Context(
            pull_request=request.context.pull_request,
            repository=request.context.repository,
            run_data=request.context.run_data,
        )
        try:
            self._plugin.on_pr_merged(ctx=ctx)
            return saturnbot_pb2.OnPrMergedResponse(error=None)
        except Exception:
            return saturnbot_pb2.OnPrMergedResponse(
                error=traceback.format_exc(),
            )


def serve(port: int, shutdown: controller.Servicer, plugin: Plugin):
    server = grpc.server(futures.ThreadPoolExecutor(max_workers=10))
    server.add_insecure_port(f"{BIND_IP}:{port}")

    # Set up redirection of stderr and stdout.
    stdio_queue: queue.SimpleQueue = queue.SimpleQueue()
    stdio_servicer = stdio.Servicer(q=stdio_queue, shutdown_ctrl=shutdown)
    sys.stderr = stdio.Adapter(channel=grpc_stdio_pb2.StdioData.STDERR, q=stdio_queue)
    sys.stdout = stdio.Adapter(channel=grpc_stdio_pb2.StdioData.STDOUT, q=stdio_queue)
    grpc_stdio_pb2_grpc.add_GRPCStdioServicer_to_server(
        servicer=stdio_servicer, server=server
    )

    saturnbot_pb2_grpc.add_PluginServiceServicer_to_server(
        servicer=PluginService(plugin), server=server
    )

    grpc_controller_pb2_grpc.add_GRPCControllerServicer_to_server(
        servicer=shutdown, server=server
    )

    health = HealthServicer()
    health.set("plugin", health_pb2.HealthCheckResponse.ServingStatus.Value("SERVING"))
    health_pb2_grpc.add_HealthServicer_to_server(servicer=health, server=server)
    server.start()
    return server


def serve_plugin(plugin: Plugin) -> None:
    port = _find_open_port()
    grpc_controller = controller.Servicer()
    server = serve(port=port, shutdown=grpc_controller, plugin=plugin)
    # Default sys.stdout is being redirected.
    # Use the original stream to write to stdout of the plugin process.
    print(f"1|1|tcp|{BIND_IP}:{port}|grpc", file=sys_stdout)
    sys_stdout.flush()
    try:
        while True:
            time.sleep(0.1)
            if grpc_controller.is_shut_down is True:
                server.stop(0)
                sys.exit(0)
    except KeyboardInterrupt:
        server.stop(0)


def _find_open_port() -> int:
    while True:
        port = random.randrange(start=11000, stop=12000)
        s = socket.socket(socket.AF_INET, socket.SOCK_STREAM)
        try:
            s.bind((BIND_IP, port))
            return port
        except socket.error as e:
            if e.errno != errno.EADDRINUSE:
                raise e
        finally:
            if s is not None:
                s.close()



# -*- coding: utf-8 -*-
# This Source Code Form is subject to the terms of the Mozilla Public
# License, v. 2.0. If a copy of the MPL was not distributed with this
# file, You can obtain one at https://mozilla.org/MPL/2.0/.

# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: saturn_bot/protocol/v1/saturnbot.proto
# Protobuf Python Version: 4.25.3
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n&saturn_bot/protocol/v1/saturnbot.proto\x12\x0bprotocol.v1\"[\n\x15\x45xecuteActionsRequest\x12\x12\n\x04path\x18\x01 \x01(\tR\x04path\x12.\n\x07\x63ontext\x18\x02 \x01(\x0b\x32\x14.protocol.v1.ContextR\x07\x63ontext\"\xd2\x01\n\x16\x45xecuteActionsResponse\x12\x19\n\x05\x65rror\x18\x01 \x01(\tH\x00R\x05\x65rror\x88\x01\x01\x12K\n\x08run_data\x18\x04 \x03(\x0b\x32\x30.protocol.v1.ExecuteActionsResponse.RunDataEntryR\x07runData\x1a:\n\x0cRunDataEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12\x14\n\x05value\x18\x02 \x01(\tR\x05value:\x02\x38\x01\x42\x08\n\x06_errorJ\x04\x08\x02\x10\x03J\x04\x08\x03\x10\x04\"G\n\x15\x45xecuteFiltersRequest\x12.\n\x07\x63ontext\x18\x01 \x01(\x0b\x32\x14.protocol.v1.ContextR\x07\x63ontext\"\xe8\x01\n\x16\x45xecuteFiltersResponse\x12\x14\n\x05match\x18\x01 \x01(\x08R\x05match\x12\x19\n\x05\x65rror\x18\x02 \x01(\tH\x00R\x05\x65rror\x88\x01\x01\x12K\n\x08run_data\x18\x05 \x03(\x0b\x32\x30.protocol.v1.ExecuteFiltersResponse.RunDataEntryR\x07runData\x1a:\n\x0cRunDataEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12\x14\n\x05value\x18\x02 \x01(\tR\x05value:\x02\x38\x01\x42\x08\n\x06_errorJ\x04\x08\x03\x10\x04J\x04\x08\x04\x10\x05\"\x90\x01\n\x10GetPluginRequest\x12\x41\n\x06\x63onfig\x18\x01 \x03(\x0b\x32).protocol.v1.GetPluginRequest.ConfigEntryR\x06\x63onfig\x1a\x39\n\x0b\x43onfigEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12\x14\n\x05value\x18\x02 \x01(\tR\x05value:\x02\x38\x01\"h\n\x11GetPluginResponse\x12\x12\n\x04name\x18\x01 \x01(\tR\x04name\x12\x1a\n\x08priority\x18\x02 \x01(\x05R\x08priority\x12\x19\n\x05\x65rror\x18\x03 \x01(\tH\x00R\x05\x65rror\x88\x01\x01\x42\x08\n\x06_error\"\x95\x02\n\x07\x43ontext\x12\x37\n\nrepository\x18\x01 \x01(\x0b\x32\x17.protocol.v1.RepositoryR\nrepository\x12@\n\x0cpull_request\x18\x02 \x01(\x0b\x32\x18.protocol.v1.PullRequestH\x00R\x0bpullRequest\x88\x01\x01\x12<\n\x08run_data\x18\x04 \x03(\x0b\x32!.protocol.v1.Context.RunDataEntryR\x07runData\x1a:\n\x0cRunDataEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12\x14\n\x05value\x18\x02 \x01(\tR\x05value:\x02\x38\x01\x42\x0f\n\r_pull_requestJ\x04\x08\x03\x10\x04\">\n\x0bPullRequest\x12\x16\n\x06number\x18\x01 \x01(\x03R\x06number\x12\x17\n\x07web_url\x18\x02 \x01(\tR\x06webUrl\"\x8c\x01\n\nRepository\x12\x1b\n\tfull_name\x18\x01 \x01(\tR\x08\x66ullName\x12$\n\x0e\x63lone_url_http\x18\x02 \x01(\tR\x0c\x63loneUrlHttp\x12\"\n\rclone_url_ssh\x18\x03 \x01(\tR\x0b\x63loneUrlSsh\x12\x17\n\x07web_url\x18\x04 \x01(\tR\x06webUrl\"C\n\x11OnPrClosedRequest\x12.\n\x07\x63ontext\x18\x01 \x01(\x0b\x32\x14.protocol.v1.ContextR\x07\x63ontext\"9\n\x12OnPrClosedResponse\x12\x19\n\x05\x65rror\x18\x01 \x01(\tH\x00R\x05\x65rror\x88\x01\x01\x42\x08\n\x06_error\"D\n\x12OnPrCreatedRequest\x12.\n\x07\x63ontext\x18\x01 \x01(\x0b\x32\x14.protocol.v1.ContextR\x07\x63ontext\":\n\x13OnPrCreatedResponse\x12\x19\n\x05\x65rror\x18\x01 \x01(\tH\x00R\x05\x65rror\x88\x01\x01\x42\x08\n\x06_error\"C\n\x11OnPrMergedRequest\x12.\n\x07\x63ontext\x18\x01 \x01(\x0b\x32\x14.protocol.v1.ContextR\x07\x63ontext\"9\n\x12OnPrMergedResponse\x12\x19\n\x05\x65rror\x18\x01 \x01(\tH\x00R\x05\x65rror\x88\x01\x01\x42\x08\n\x06_error2\x8d\x04\n\rPluginService\x12[\n\x0e\x45xecuteActions\x12\".protocol.v1.ExecuteActionsRequest\x1a#.protocol.v1.ExecuteActionsResponse\"\x00\x12[\n\x0e\x45xecuteFilters\x12\".protocol.v1.ExecuteFiltersRequest\x1a#.protocol.v1.ExecuteFiltersResponse\"\x00\x12L\n\tGetPlugin\x12\x1d.protocol.v1.GetPluginRequest\x1a\x1e.protocol.v1.GetPluginResponse\"\x00\x12O\n\nOnPrClosed\x12\x1e.protocol.v1.OnPrClosedRequest\x1a\x1f.protocol.v1.OnPrClosedResponse\"\x00\x12R\n\x0bOnPrCreated\x12\x1f.protocol.v1.OnPrCreatedRequest\x1a .protocol.v1.OnPrCreatedResponse\"\x00\x12O\n\nOnPrMerged\x12\x1e.protocol.v1.OnPrMergedRequest\x1a\x1f.protocol.v1.OnPrMergedResponse\"\x00\x42n\n\x0f\x63om.protocol.v1B\x0eSaturnbotProtoP\x01\xa2\x02\x03PXX\xaa\x02\x0bProtocol.V1\xca\x02\x0bProtocol\\V1\xe2\x02\x17Protocol\\V1\\GPBMetadata\xea\x02\x0cProtocol::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'saturn_bot.protocol.v1.saturnbot_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  _globals['DESCRIPTOR']._options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\017com.protocol.v1B\016SaturnbotProtoP\001\242\002\003PXX\252\002\013Protocol.V1\312\002\013Protocol\\V1\342\002\027Protocol\\V1\\GPBMetadata\352\002\014Protocol::V1'
  _globals['_EXECUTEACTIONSRESPONSE_RUNDATAENTRY']._options = None
  _globals['_EXECUTEACTIONSRESPONSE_RUNDATAENTRY']._serialized_options = b'8\001'
  _globals['_EXECUTEFILTERSRESPONSE_RUNDATAENTRY']._options = None
  _globals['_EXECUTEFILTERSRESPONSE_RUNDATAENTRY']._serialized_options = b'8\001'
  _globals['_GETPLUGINREQUEST_CONFIGENTRY']._options = None
  _globals['_GETPLUGINREQUEST_CONFIGENTRY']._serialized_options = b'8\001'
  _globals['_CONTEXT_RUNDATAENTRY']._options = None
  _globals['_CONTEXT_RUNDATAENTRY']._serialized_options = b'8\001'
  _globals['_EXECUTEACTIONSREQUEST']._serialized_start=55
  _globals['_EXECUTEACTIONSREQUEST']._serialized_end=146
  _globals['_EXECUTEACTIONSRESPONSE']._serialized_start=149
  _globals['_EXECUTEACTIONSRESPONSE']._serialized_end=359
  _globals['_EXECUTEACTIONSRESPONSE_RUNDATAENTRY']._serialized_start=279
  _globals['_EXECUTEACTIONSRESPONSE_RUNDATAENTRY']._serialized_end=337
  _globals['_EXECUTEFILTERSREQUEST']._serialized_start=361
  _globals['_EXECUTEFILTERSREQUEST']._serialized_end=432
  _globals['_EXECUTEFILTERSRESPONSE']._serialized_start=435
  _globals['_EXECUTEFILTERSRESPONSE']._serialized_end=667
  _globals['_EXECUTEFILTERSRESPONSE_RUNDATAENTRY']._serialized_start=279
  _globals['_EXECUTEFILTERSRESPONSE_RUNDATAENTRY']._serialized_end=337
  _globals['_GETPLUGINREQUEST']._serialized_start=670
  _globals['_GETPLUGINREQUEST']._serialized_end=814
  _globals['_GETPLUGINREQUEST_CONFIGENTRY']._serialized_start=757
  _globals['_GETPLUGINREQUEST_CONFIGENTRY']._serialized_end=814
  _globals['_GETPLUGINRESPONSE']._serialized_start=816
  _globals['_GETPLUGINRESPONSE']._serialized_end=920
  _globals['_CONTEXT']._serialized_start=923
  _globals['_CONTEXT']._serialized_end=1200
  _globals['_CONTEXT_RUNDATAENTRY']._serialized_start=279
  _globals['_CONTEXT_RUNDATAENTRY']._serialized_end=337
  _globals['_PULLREQUEST']._serialized_start=1202
  _globals['_PULLREQUEST']._serialized_end=1264
  _globals['_REPOSITORY']._serialized_start=1267
  _globals['_REPOSITORY']._serialized_end=1407
  _globals['_ONPRCLOSEDREQUEST']._serialized_start=1409
  _globals['_ONPRCLOSEDREQUEST']._serialized_end=1476
  _globals['_ONPRCLOSEDRESPONSE']._serialized_start=1478
  _globals['_ONPRCLOSEDRESPONSE']._serialized_end=1535
  _globals['_ONPRCREATEDREQUEST']._serialized_start=1537
  _globals['_ONPRCREATEDREQUEST']._serialized_end=1605
  _globals['_ONPRCREATEDRESPONSE']._serialized_start=1607
  _globals['_ONPRCREATEDRESPONSE']._serialized_end=1665
  _globals['_ONPRMERGEDREQUEST']._serialized_start=1667
  _globals['_ONPRMERGEDREQUEST']._serialized_end=1734
  _globals['_ONPRMERGEDRESPONSE']._serialized_start=1736
  _globals['_ONPRMERGEDRESPONSE']._serialized_end=1793
  _globals['_PLUGINSERVICE']._serialized_start=1796
  _globals['_PLUGINSERVICE']._serialized_end=2321
# @@protoc_insertion_point(module_scope)



# This Source Code Form is subject to the terms of the Mozilla Public
# License, v. 2.0. If a copy of the MPL was not distributed with this
# file, You can obtain one at https://mozilla.org/MPL/2.0/.

from saturn_bot.plugin import grpc_controller_pb2_grpc


class Servicer(grpc_controller_pb2_grpc.GRPCControllerServicer):
    def __init__(self):
        self.is_shut_down = False

    def Shutdown(self, request, context):
        self.is_shut_down = True
